##  Import Templates
We offer import templates for modeling the major IT systems mentioned above. You will always find them on the information box, such as this one:
**Note**
Information boxes like this one will provide a link to the import template below each model.
In order to successfully use the templates, below are some helpful tips:
  * Download the .zip archive to your computer and save it somewhere where you will easily find it again
  * Make sure to import the Excel files in the correct order, as indicated by the numbers in the first part of the file names
  * After you have finished importing the files, you can start to recreate the best practice model in the diagrams section of SAP LeanIX


YesNo
Send
